@@ -21,14 +21,17 @@ def main(
         None, envvar='ASYNCAPI_SERVER_BINDINGS'
     ),
     api_module: str = typer.Option('', envvar='ASYNCAPI_MODULE'),
-    republish_errors: bool = typer.Option(
-        True, envvar='ASYNCAPI_REPUBLISH_ERRORS'
+    republish_errors: Optional[bool] = typer.Option(
+        None, envvar='ASYNCAPI_REPUBLISH_ERRORS'
     ),
     channel: Optional[str] = typer.Option(None, envvar='ASYNCAPI_CHANNEL'),
     workers: int = typer.Option(1, envvar='ASYNCAPI_WORKERS'),
     channels_subscribes: Optional[str] = typer.Option(
         None, envvar='ASYNCAPI_CHANNELS_SUBSCRIBES'
     ),
+    republish_errors_channels: Optional[str] = typer.Option(
+        None, envvar='ASYNCAPI_REPUBLISH_ERRORS_CHANNELS'
+    ),
 ) -> None:
 
     if url is None:
@@ -41,6 +44,7 @@ def main(
             server_bindings=server_bindings,
             republish_errors=republish_errors,
             channels_subscribes=channels_subscribes,
+            republish_errors_channels=republish_errors_channels,
         )
 
     else:
@@ -51,6 +55,7 @@ def main(
             server_bindings=server_bindings,
             republish_errors=republish_errors,
             channels_subscribes=channels_subscribes,
+            republish_errors_channels=republish_errors_channels,
         )
 
     fork_app(workers)
